@@ -596,8 +596,18 @@ Ext.define('MP.grid.plugin.FilterBar', {
             if (me.enableOperators
                 && column.filter.type != 'combo'
                 && !column.filter.noOperatorPlugin) {
+                var operator = null;
+                for(var i=0, l=me.filterArray.length; i<l; i++) {
+                    var filter = me.filterArray[i];
+                    if(filter.operator && column.dataIndex == filter.property) {
+                        operator = filter.operator;
+                        break;
+                    }
+                };
+
                 plugins.push({
                     ptype: 'operatorbutton',
+                    operator: operator,
                     listeners: {
                         operatorchanged: function(fld, newop) {
                             me.columns.get(fld.dataIndex).filter.operator = newop;
